@@ -2,6 +2,7 @@
 #'
 #' @name mlr_learners_clust.cobweb
 #' @include LearnerClust.R
+#' @include aaa.R
 #'
 #' @description
 #' A [LearnerClust] for Cobweb clustering implemented in [RWeka::Cobweb()].
@@ -32,6 +33,7 @@ LearnerClustCobweb = R6Class("LearnerClustCobweb",
         param_set = ps,
         properties = c("partitional", "exclusive", "complete"),
         packages = "RWeka",
+        man = "mlr3cluster::mlr_learners_clust.cobweb",
         label = "Cobweb Clustering"
       )
     }
@@ -55,3 +57,5 @@ LearnerClustCobweb = R6Class("LearnerClustCobweb",
     }
   )
 )
+
+learners[["clust.cobweb"]] = LearnerClustCobweb
