@@ -2,6 +2,7 @@
 #'
 #' @name mlr_learners_clust.SimpleKMeans
 #' @include LearnerClust.R
+#' @include aaa.R
 #'
 #' @description
 #' A [LearnerClust] for Simple K Means clustering implemented in [RWeka::SimpleKMeans()].
@@ -46,6 +47,7 @@ LearnerClustSimpleKMeans = R6Class("LearnerClustSimpleKMeans",
         param_set = ps,
         properties = c("partitional", "exclusive", "complete"),
         packages = "RWeka",
+        man = "mlr3cluster::mlr_learners_clust.SimpleKMeans",
         label = "K-Means (Weka)"
       )
     }
@@ -70,3 +72,5 @@ LearnerClustSimpleKMeans = R6Class("LearnerClustSimpleKMeans",
     }
   )
 )
+
+learners[["clust.SimpleKMeans"]] = LearnerClustSimpleKMeans
